amqplib Transport - kombu.transport.pyamqplib — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# amqplib Transport - kombu.transport.pyamqplib

class `kombu.transport.pyamqplib.` `Channel`(connection, channel_id=None, auto_decode=True)
  class `Message`(channel, msg, **kwargs)

    A message received by the broker.

    `body`

      The message body.

    `delivery_tag`

      The message delivery tag, uniquely identifying this message.

    `channel`

      The channel instance the message was received on.

  `Channel.` `message_to_python`(raw_message)

    Convert encoded message body back to a Python value.

  `Channel.` `prepare_message`(message_data, priority=None, content_type=None, content_encoding=None, headers=None, properties=None)

    Encapsulate data into a AMQP message.

class `kombu.transport.pyamqplib.` `Connection`(*args, **kwargs)
  `channel`(channel_id=None)
  `drain_events`(allowed_methods=None, timeout=None)

    Wait for an event on any channel.

  `read_timeout`(timeout=None)
  `wait_multi`(channels, allowed_methods=None, timeout=None)

    Wait for an event on a channel.

class `kombu.transport.pyamqplib.` `Message`(channel, msg, **kwargs)

  A message received by the broker.

  `body`

    The message body.

  `delivery_tag`

    The message delivery tag, uniquely identifying this message.

  `channel`

    The channel instance the message was received on.

class `kombu.transport.pyamqplib.` `Transport`(client, **kwargs)
  `close_connection`(connection)

    Close the AMQP broker connection.

  `create_channel`(connection)
  `drain_events`(connection, **kwargs)
  `establish_connection`()

    Establish connection to the AMQP broker.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »